# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_config import cfg

os_vif_contrail_vrouter_group = cfg.OptGroup(
    'os_vif_contrail_vrouter',
    title='TungstenFabric VIF Options',
    help="""
Configuration options for operations with TungstenFabric (aka OpenContrail)
VIFs.
""")

os_vif_contrail_vrouter_opts = [
    cfg.PortOpt('vrouter_port',
        required=False,
        default=None,
        help="""
The port number which is used by the nova VIF methods to connect to
tungstenfabric vrouter for port plug/unplug operations.

Sometimes we need to change default port (9091) to prevent it's intersection
with other services, which try to occupy same port.
This option can be used in containerized environments with calico cni,
which uses same default tcp port.
"""),
]


def register_opts(conf):
    conf.register_group(os_vif_contrail_vrouter_group)
    conf.register_opts(os_vif_contrail_vrouter_opts,
                       group=os_vif_contrail_vrouter_group)


def list_opts():
    return {os_vif_contrail_vrouter_group: os_vif_contrail_vrouter_opts}
