#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from nova import objects
from nova.scheduler.filters import cpu_flags_filter
from nova import test
from nova.tests.unit.scheduler import fakes
from nova.tests import uuidsentinel as uuids


class CpuFlagsFilter(test.NoDBTestCase):

    def setUp(self):
        super(CpuFlagsFilter, self).setUp()
        self.filt_cls = cpu_flags_filter.CpuFlagsFilter()

    def test_not_live_migration(self):
        host = fakes.FakeHostState('fake-host', 'fake-node', {})
        spec_obj = objects.RequestSpec(
            image=objects.ImageMeta(id=uuids.image_ref), scheduler_hints={})
        self.assertTrue(self.filt_cls.host_passes(host, spec_obj))

    def test_cpu_not_match(self):
        host = fakes.FakeHostState('fake-host', 'fake-node', {})
        host.cpu_info = '{"features": ["a", "b", "c"], "arch": "x86_64"}'
        spec_obj = objects.RequestSpec(
            image=objects.ImageMeta(id=uuids.image_ref),
            scheduler_hints={"__operation":
                             ["live-migration",
                              '{"features": ["x", "y"], "arch": "x86_64"}']})
        self.assertFalse(self.filt_cls.host_passes(host, spec_obj))

    def test_cpu_match(self):
        host = fakes.FakeHostState('fake-host', 'fake-node', {})
        host.cpu_info = '{"features": ["a", "b", "c"], "arch": "x86_64"}'
        spec_obj = objects.RequestSpec(
            image=objects.ImageMeta(id=uuids.image_ref),
            scheduler_hints={"__operation":
                             ["live-migration",
                              '{"features": ["a", "b"], "arch": "x86_64"}']})
        self.assertTrue(self.filt_cls.host_passes(host, spec_obj))
